@@ -12,3 +12,5 @@ class RuleScore:
     rule_description: str
     rule_score: float
     attribute_scores: List[RuleAttributeScore]
+    rule_unweighted_score: float
+    rule_weight: float
