@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import List, Optional, Union
 
 # noinspection PyPackageRequirements
 from fhir.resources.bundle import Bundle
@@ -21,16 +21,21 @@ from helix_personmatching.logics.rules_generator import RulesGenerator
 from helix_personmatching.logics.score_calculator import ScoreCalculator
 from helix_personmatching.logics.scoring_input import ScoringInput
 from helix_personmatching.models.rule import Rule
+from helix_personmatching.models.scoring_option import ScoringOption
 
 
 class Matcher:
     # noinspection PyMethodMayBeStatic
     def score_inputs(
-        self, *, source: List[ScoringInput], target: List[ScoringInput]
+        self,
+        *,
+        source: List[ScoringInput],
+        target: List[ScoringInput],
+        options: Optional[List[ScoringOption]] = None
     ) -> List[MatchScoreWithoutThreshold]:
         assert source
         assert target
-        rules: List[Rule] = RulesGenerator.generate_rules()
+        rules: List[Rule] = RulesGenerator.generate_rules(options=options)
 
         result: List[MatchScoreWithoutThreshold] = []
 
@@ -50,6 +55,7 @@ class Matcher:
         target: List[ScoringInput],
         threshold: float = 80.0,
         verbose: bool = False,
+        options: Optional[List[ScoringOption]] = None
     ) -> List[MatchScore]:
         assert source
         assert isinstance(source, list)
@@ -65,7 +71,9 @@ class Matcher:
                 threshold=threshold,
                 matched=(score.total_score >= threshold),
             )
-            for score in self.score_inputs(source=source, target=target)
+            for score in self.score_inputs(
+                source=source, target=target, options=options
+            )
         ]
 
     def match(
@@ -75,6 +83,7 @@ class Matcher:
         target_json: Union[str, List[str]],
         threshold: float = 80.0,
         verbose: bool = False,
+        options: Optional[List[ScoringOption]] = None
     ) -> List[MatchScore]:
         assert source_json
         assert isinstance(source_json, str) or isinstance(source_json, list)
@@ -88,7 +97,11 @@ class Matcher:
             resource_json=target_json
         )
         match_score: List[MatchScore] = self.match_scoring_inputs(
-            source=source, target=target, threshold=threshold, verbose=verbose
+            source=source,
+            target=target,
+            threshold=threshold,
+            verbose=verbose,
+            options=options,
         )
         return match_score
 
@@ -99,6 +112,7 @@ class Matcher:
         target: Union[Patient, Person, Bundle],
         threshold: float = 80.0,
         verbose: bool = False,
+        options: Optional[List[ScoringOption]] = None
     ) -> List[MatchScore]:
         source_scoring_inputs: List[
             ScoringInput
@@ -111,4 +125,5 @@ class Matcher:
             target=target_scoring_inputs,
             threshold=threshold,
             verbose=verbose,
+            options=options,
         )
