@@ -8,6 +8,7 @@ from helix_personmatching.matchers.matcher import Matcher
 
 
 def test_hapi_partial_match() -> None:
+    print("")
     data_dir: Path = Path(__file__).parent.joinpath("./person_data")
 
     with open(data_dir.joinpath("bwell_master_person.json")) as file:
@@ -28,10 +29,10 @@ def test_hapi_partial_match() -> None:
     score = scores[0]
 
     print(f"\r\nscore.matched: {score.matched}")
-    assert score.matched is False
+    assert score.matched is True
 
     print(f"\r\nscore.total_score: {score.total_score}")
-    assert score.total_score == 77.52976190476191
+    assert score.total_score == 94.56845238095238
 
     score_dict = dataclasses.asdict(score)
 
