@@ -8,6 +8,7 @@ from helix_personmatching.matchers.matcher import Matcher
 
 
 def test_walgreens_partial_match() -> None:
+    print("")
     data_dir: Path = Path(__file__).parent.joinpath("./person_data")
 
     with open(data_dir.joinpath("bwell_master_person.json")) as file:
@@ -28,10 +29,10 @@ def test_walgreens_partial_match() -> None:
     score = scores[0]
 
     print(f"score.matched: {score.matched}")
-    assert score.matched is False
+    assert score.matched is True
 
     print(f"score.total_score: {score.total_score}")
-    assert score.total_score == 30.69940476190476
+    assert score.total_score == 88.25892857142858
 
     score_dict = dataclasses.asdict(score)
 
